<?php

/**
 * @file tests/classes/core/PKPComponentRouterTest.inc.php
 *
 * Copyright (c) 2003-2009 John Willinsky
 * Distributed under the GNU GPL v2. For full terms see the file docs/COPYING.
 *
 * @class PKPComponentRouterTest
 * @ingroup tests
 * @see PKPComponentRouter
 *
 * @brief Tests for the PKPComponentRouter class.
 */

import('core.PKPComponentRouter');
import('tests.classes.core.PKPRouterTest');

class PKPComponentRouterTest extends PKPRouterTest {
	protected function setUp() {
		$this->router = new PKPComponentRouter();
	}

	public function testSupports() {
		// This method only exists to override and neutralize the parent class'
		// testSupports() which is not relevant for component routers.
	}

	/**
	 * @covers PKPComponentRouter::supports
	 * @covers PKPComponentRouter::getRpcServiceEndpoint
	 * @covers PKPComponentRouter::_getValidatedServiceEndpointParts
	 * @covers PKPComponentRouter::_retrieveServiceEndpointParts
	 * @covers PKPComponentRouter::_validateServiceEndpointParts
	 * @covers PKPComponentRouter::_camelize
	 */
	public function testSupportsWithPathinfoSuccessful() {
		$mockApplication = $this->_setUpMockEnvironment(self::PATHINFO_ENABLED);

		$_SERVER = array(
			'PATH_INFO' => '/context1/context2/$$$call$$$/grid/citation/citation-grid/fetch'
		);
		self::assertTrue($this->router->supports($this->request));
	}

	/**
	 * @covers PKPComponentRouter::supports
	 * @covers PKPComponentRouter::getRpcServiceEndpoint
	 * @covers PKPComponentRouter::_getValidatedServiceEndpointParts
	 * @covers PKPComponentRouter::_retrieveServiceEndpointParts
	 * @covers PKPComponentRouter::_validateServiceEndpointParts
	 * @covers PKPComponentRouter::_camelize
	 */
	public function testSupportsWithPathinfoUnsuccessfulNoComponentNotEnoughPathElements() {
		$mockApplication = $this->_setUpMockEnvironment(self::PATHINFO_ENABLED);

		$_SERVER = array(
			'PATH_INFO' => '/context1/context2/page/operation'
		);
		self::assertEquals('', $this->router->getRequestedComponent($this->request));
		self::assertFalse($this->router->supports($this->request));
	}

	/**
	 * @covers PKPComponentRouter::supports
	 * @covers PKPComponentRouter::getRpcServiceEndpoint
	 * @covers PKPComponentRouter::_getValidatedServiceEndpointParts
	 * @covers PKPComponentRouter::_retrieveServiceEndpointParts
	 * @covers PKPComponentRouter::_validateServiceEndpointParts
	 * @covers PKPComponentRouter::_camelize
	 */
	public function testSupportsWithPathinfoUnsuccessfulNoComponentNoMarker() {
		$mockApplication = $this->_setUpMockEnvironment(self::PATHINFO_ENABLED);

		$_SERVER = array(
			'PATH_INFO' => '/context1/context2/path/to/handler/operation'
		);
		self::assertEquals('', $this->router->getRequestedComponent($this->request));
		self::assertFalse($this->router->supports($this->request));
	}

	/**
	 * @covers PKPComponentRouter::supports
	 * @covers PKPComponentRouter::getRpcServiceEndpoint
	 * @covers PKPComponentRouter::_getValidatedServiceEndpointParts
	 * @covers PKPComponentRouter::_retrieveServiceEndpointParts
	 * @covers PKPComponentRouter::_validateServiceEndpointParts
	 * @covers PKPComponentRouter::_camelize
	 */
	public function testSupportsWithPathinfoUnsuccessfulComponentFileDoesNotExist() {
		$mockApplication = $this->_setUpMockEnvironment(self::PATHINFO_ENABLED);

		$_SERVER = array(
			'PATH_INFO' => '/context1/context2/$$$call$$$/inexistent/component/fetch'
		);
		self::assertEquals('inexistent.ComponentHandler', $this->router->getRequestedComponent($this->request));
		self::assertFalse($this->router->supports($this->request));
	}

	/**
	 * @covers PKPComponentRouter::supports
	 * @covers PKPComponentRouter::getRpcServiceEndpoint
	 * @covers PKPComponentRouter::_getValidatedServiceEndpointParts
	 * @covers PKPComponentRouter::_retrieveServiceEndpointParts
	 * @covers PKPComponentRouter::_validateServiceEndpointParts
	 * @covers PKPComponentRouter::_camelize
	 */
	public function testSupportsWithPathinfoUnsuccessfulOperationDoesNotExist() {
		$mockApplication = $this->_setUpMockEnvironment(self::PATHINFO_ENABLED);

		$_SERVER = array(
			'PATH_INFO' => '/context1/context2/$$$call$$$/grid/citation/citation-grid/inexistent-operation'
		);
		self::assertEquals('grid.citation.CitationGridHandler', $this->router->getRequestedComponent($this->request));
		self::assertEquals('inexistentOperation', $this->router->getRequestedOp($this->request));
		self::assertFalse($this->router->supports($this->request));
		self::assertTrue(class_exists('CitationGridHandler'));
	}


	/**
	 * @covers PKPComponentRouter::supports
	 * @covers PKPComponentRouter::getRpcServiceEndpoint
	 * @covers PKPComponentRouter::_getValidatedServiceEndpointParts
	 * @covers PKPComponentRouter::_retrieveServiceEndpointParts
	 * @covers PKPComponentRouter::_validateServiceEndpointParts
	 * @covers PKPComponentRouter::_camelize
	 */
	public function testSupportsWithPathinfoUnsuccessfulOperationIsNotRemoteAccessible() {
		$mockApplication = $this->_setUpMockEnvironment(self::PATHINFO_ENABLED);

		$_SERVER = array(
			'PATH_INFO' => '/context1/context2/$$$call$$$/grid/citation/citation-grid/private-method'
		);
		self::assertEquals('grid.citation.CitationGridHandler', $this->router->getRequestedComponent($this->request));
		self::assertEquals('privateMethod', $this->router->getRequestedOp($this->request));
		self::assertFalse($this->router->supports($this->request));
		self::assertTrue(class_exists('CitationGridHandler'));
		$testInstance = new CitationGridHandler();
		self::assertTrue(in_array('privateMethod', get_class_methods('CitationGridHandler')));
		self::assertFalse(in_array('privateMethod', $testInstance->getRemoteOperations()));
	}

	/**
	 * @covers PKPComponentRouter::supports
	 * @covers PKPComponentRouter::getRpcServiceEndpoint
	 * @covers PKPComponentRouter::_getValidatedServiceEndpointParts
	 * @covers PKPComponentRouter::_retrieveServiceEndpointParts
	 * @covers PKPComponentRouter::_validateServiceEndpointParts
	 * @covers PKPComponentRouter::_camelize
	 */
	public function testSupportsWithPathinfoUnsuccessfulComponentIsNotAHandler() {
		$mockApplication = $this->_setUpMockEnvironment(self::PATHINFO_ENABLED);

		$_SERVER = array(
			'PATH_INFO' => '/context1/context2/$$$call$$$/grid/citation/citation-row/fetch'
		);
		self::assertEquals('grid.citation.CitationRowHandler', $this->router->getRequestedComponent($this->request));
		self::assertEquals('fetch', $this->router->getRequestedOp($this->request));
		self::assertFalse($this->router->supports($this->request));
		self::assertTrue(class_exists('CitationRowHandler'));
		$testInstance = new CitationRowHandler();
		self::assertTrue(in_array('fetch', get_class_methods('CitationRowHandler')));
		self::assertFalse(is_a($testInstance, 'PKPHandler'));
	}

	/**
	 * @covers PKPComponentRouter::getRequestedComponent
	 * @covers PKPComponentRouter::_getValidatedServiceEndpointParts
	 * @covers PKPComponentRouter::_retrieveServiceEndpointParts
	 * @covers PKPComponentRouter::_validateServiceEndpointParts
	 * @covers PKPComponentRouter::_camelize
	 */
	public function testGetRequestedComponentWithPathinfo() {
		$mockApplication = $this->_setUpMockEnvironment(self::PATHINFO_ENABLED);

		$_SERVER = array(
			'PATH_INFO' => '/context1/context2/$$$call$$$/path/to/some-component/operation'
		);
		self::assertEquals('path.to.SomeComponentHandler', $this->router->getRequestedComponent($this->request));
	}

	/**
	 * @covers PKPComponentRouter::getRequestedComponent
	 * @covers PKPComponentRouter::_getValidatedServiceEndpointParts
	 * @covers PKPComponentRouter::_retrieveServiceEndpointParts
	 * @covers PKPComponentRouter::_validateServiceEndpointParts
	 * @covers PKPComponentRouter::_camelize
	 */
	public function testGetRequestedComponentWithPathinfoAndMalformedComponentString() {
		$mockApplication = $this->_setUpMockEnvironment(self::PATHINFO_ENABLED);

		$_SERVER = array(
			'PATH_INFO' => '/context1/context2/$$$call$$$/path/to/some-#component/operation'
		);
		self::assertEquals('', $this->router->getRequestedComponent($this->request));
	}

	/**
	 * @covers PKPComponentRouter::getRequestedComponent
	 * @covers PKPComponentRouter::_getValidatedServiceEndpointParts
	 * @covers PKPComponentRouter::_retrieveServiceEndpointParts
	 * @covers PKPComponentRouter::_validateServiceEndpointParts
	 * @covers PKPComponentRouter::_camelize
	 */
	public function testGetRequestedComponentWithPathinfoDisabled() {
		$mockApplication = $this->_setUpMockEnvironment(self::PATHINFO_DISABLED);

		$_GET = array(
			'component' => 'path.to.some-component',
			'op' => 'operation'
		);
		self::assertEquals('path.to.SomeComponentHandler', $this->router->getRequestedComponent($this->request));
	}

	/**
	 * @covers PKPComponentRouter::getRequestedOp
	 * @covers PKPComponentRouter::_getValidatedServiceEndpointParts
	 * @covers PKPComponentRouter::_retrieveServiceEndpointParts
	 * @covers PKPComponentRouter::_validateServiceEndpointParts
	 * @covers PKPComponentRouter::_camelize
	 */
	public function testGetRequestedOpWithPathinfo() {
		$mockApplication = $this->_setUpMockEnvironment(self::PATHINFO_ENABLED);

		$_SERVER = array(
			'PATH_INFO' => '/context1/context2/$$$call$$$/path/to/some-component/some-op'
		);
		self::assertEquals('someOp', $this->router->getRequestedOp($this->request));
	}

	/**
	 * @covers PKPComponentRouter::getRequestedOp
	 * @covers PKPComponentRouter::_getValidatedServiceEndpointParts
	 * @covers PKPComponentRouter::_retrieveServiceEndpointParts
	 * @covers PKPComponentRouter::_validateServiceEndpointParts
	 * @covers PKPComponentRouter::_camelize
	 */
	public function testGetRequestedOpWithPathinfoDisabled() {
		$mockApplication = $this->_setUpMockEnvironment(self::PATHINFO_DISABLED);

		$_GET = array(
			'component' => 'path.to.some-component',
			'op' => 'some-op'
		);
		self::assertEquals('someOp', $this->router->getRequestedOp($this->request));
	}

	/**
	 * @covers PKPComponentRouter::getRequestedOp
	 * @covers PKPComponentRouter::_getValidatedServiceEndpointParts
	 * @covers PKPComponentRouter::_retrieveServiceEndpointParts
	 * @covers PKPComponentRouter::_validateServiceEndpointParts
	 * @covers PKPComponentRouter::_camelize
	 */
	public function testGetRequestedOpWithPathinfoDisabledAndMissingComponent() {
		$mockApplication = $this->_setUpMockEnvironment(self::PATHINFO_DISABLED);

		$_GET = array(
			'op' => 'some-op'
		);
		self::assertEquals('', $this->router->getRequestedOp($this->request));
	}

	/**
	 * @covers PKPComponentRouter::getRequestedOp
	 * @covers PKPComponentRouter::_getValidatedServiceEndpointParts
	 * @covers PKPComponentRouter::_retrieveServiceEndpointParts
	 * @covers PKPComponentRouter::_validateServiceEndpointParts
	 * @covers PKPComponentRouter::_camelize
	 */
	public function testGetRequestedOpWithPathinfoAndMalformedOpString() {
		$mockApplication = $this->_setUpMockEnvironment(self::PATHINFO_ENABLED);

		$_SERVER = array(
			'PATH_INFO' => '/context1/context2/$$$call$$$/path/to/some-component/so#me-op'
		);
		self::assertEquals('', $this->router->getRequestedOp($this->request));
	}

	/**
	 * @covers PKPComponentRouter::route
	 * @covers PKPComponentRouter::getRpcServiceEndpoint
	 * @covers PKPComponentRouter::_getValidatedServiceEndpointParts
	 * @covers PKPComponentRouter::_retrieveServiceEndpointParts
	 * @covers PKPComponentRouter::_validateServiceEndpointParts
	 * @covers PKPComponentRouter::_camelize
	 */
	public function testRoute() {
		$mockApplication = $this->_setUpMockEnvironment(self::PATHINFO_ENABLED);

		$_SERVER = array(
			'PATH_INFO' => '/context1/context2/$$$call$$$/grid/citation/citation-grid/fetch'
		);
		$_GET = array(
			'arg1' => 'val1',
			'arg2' => 'val2'
		);

		// Route the request. This should call CitationGridHandler::fetch()
		// with a reference to the request object as the first argument.
		$this->router->route($this->request);

		self::assertNotNull($serviceEndpoint =& $this->router->getRpcServiceEndpoint($this->request));
		self::assertType('CitationGridHandler', $handler =& $serviceEndpoint[0]);
		$fetchArgs =& $handler->getFetchArgs();
		$expectedArgs = array(
			array('arg1' => 'val1', 'arg2' => 'val2'),
			$this->request
		);
		self::assertEquals($expectedArgs, $fetchArgs);
		self::assertSame($expectedArgs[1], $fetchArgs[1]);
	}

	/**
	 * @covers PKPComponentRouter::url
	 * @covers PKPComponentRouter::_uncamelize
	 * @covers PKPComponentRouter::_urlCanonicalizeNewContext
	 * @covers PKPComponentRouter::_urlGetBaseAndContext
	 * @covers PKPComponentRouter::_urlGetAdditionalParameters
	 * @covers PKPComponentRouter::_urlFromParts
	 */
	public function testUrlWithPathinfo() {
		$this->setTestConfiguration('request1', 'classes/core/config', false); // restful URLs
		$mockApplication = $this->_setUpMockEnvironment(self::PATHINFO_ENABLED);
		$_SERVER = array(
			'HOSTNAME' => 'mydomain.org',
			'SCRIPT_NAME' => '/index.php',
			'PATH_INFO' => '/current-context1/current-context2/$$$call$$$/current/component-class/current-op'
		);

		// Simulate context DAOs
		$this->_setUpMockDAOs();

		$result = $this->router->url($this->request);
		self::assertEquals('http://mydomain.org/index.php/current-context1/current-context2/$$$call$$$/current/component-class/current-op', $result);

		$result = $this->router->url($this->request, 'new-context1');
		self::assertEquals('http://mydomain.org/index.php/new-context1/current-context2/$$$call$$$/current/component-class/current-op', $result);

		$result = $this->router->url($this->request, array('new-context1', 'new?context2'));
		self::assertEquals('http://mydomain.org/index.php/new-context1/new%3Fcontext2/$$$call$$$/current/component-class/current-op', $result);

		$result = $this->router->url($this->request, array(), 'new.NewComponentHandler');
		self::assertEquals('http://mydomain.org/index.php/current-context1/current-context2/$$$call$$$/new/new-component/current-op', $result);

		$result = $this->router->url($this->request, array(), null, 'newOp');
		self::assertEquals('http://mydomain.org/index.php/current-context1/current-context2/$$$call$$$/current/component-class/new-op', $result);

		$result = $this->router->url($this->request, 'new-context1', 'new.NewComponentHandler');
		self::assertEquals('http://mydomain.org/index.php/new-context1/current-context2/$$$call$$$/new/new-component/current-op', $result);

		$result = $this->router->url($this->request, 'new-context1', 'new.NewComponentHandler', 'newOp');
		self::assertEquals('http://mydomain.org/index.php/new-context1/current-context2/$$$call$$$/new/new-component/new-op', $result);

		$result = $this->router->url($this->request, 'new-context1', null, 'newOp');
		self::assertEquals('http://mydomain.org/index.php/new-context1/current-context2/$$$call$$$/current/component-class/new-op', $result);

		$result = $this->router->url($this->request, array('firstContext' => null, 'secondContext' => null), null, 'newOp');
		self::assertEquals('http://mydomain.org/index.php/current-context1/current-context2/$$$call$$$/current/component-class/new-op', $result);

		$result = $this->router->url($this->request, 'new-context1', null, null, null,
			array(
				'key1' => 'val1?',
				'key2' => array('val2-1', 'val2?2')
			)
		);
		self::assertEquals('http://mydomain.org/index.php/new-context1/current-context2/$$$call$$$/current/component-class/current-op?key1=val1%3F&key2%5B%5D=val2-1&key2%5B%5D=val2%3F2', $result);

		$result = $this->router->url($this->request, 'new-context1', null, null, null, null, 'some?anchor');
		self::assertEquals('http://mydomain.org/index.php/new-context1/current-context2/$$$call$$$/current/component-class/current-op#some%3Fanchor', $result);

		$result = $this->router->url($this->request, 'new-context1', null, 'newOp', null, array('key' => 'val'), 'some-anchor');
		self::assertEquals('http://mydomain.org/index.php/new-context1/current-context2/$$$call$$$/current/component-class/new-op?key=val#some-anchor', $result);

		$result = $this->router->url($this->request, 'new-context1', null, null, null, array('key1' => 'val1', 'key2' => 'val2'), null, true);
		self::assertEquals('http://mydomain.org/index.php/new-context1/current-context2/$$$call$$$/current/component-class/current-op?key1=val1&amp;key2=val2', $result);
	}

	/**
	 * @covers PKPComponentRouter::url
	 * @covers PKPComponentRouter::_uncamelize
	 * @covers PKPComponentRouter::_urlCanonicalizeNewContext
	 * @covers PKPComponentRouter::_urlGetBaseAndContext
	 * @covers PKPComponentRouter::_urlGetAdditionalParameters
	 * @covers PKPComponentRouter::_urlFromParts
	 */
	public function testUrlWithPathinfoAndOverriddenBaseUrl() {
		$this->setTestConfiguration('request1', 'classes/core/config', false); // contains overridden context
		$mockApplication = $this->_setUpMockEnvironment(self::PATHINFO_ENABLED);
		$_SERVER = array(
			'HOSTNAME' => 'mydomain.org',
			'SCRIPT_NAME' => '/index.php',
			'PATH_INFO' => '/overridden-context/current-context2/$$$call$$$/current/component-class/current-op'
		);

		// Simulate context DAOs
		$this->_setUpMockDAOs('overridden-context');

		$result = $this->router->url($this->request);
		self::assertEquals('http://some-domain/xyz-context/current-context2/$$$call$$$/current/component-class/current-op', $result);
	}

	/**
	 * @covers PKPComponentRouter::url
	 * @covers PKPComponentRouter::_uncamelize
	 * @covers PKPComponentRouter::_urlCanonicalizeNewContext
	 * @covers PKPComponentRouter::_urlGetBaseAndContext
	 * @covers PKPComponentRouter::_urlGetAdditionalParameters
	 * @covers PKPComponentRouter::_urlFromParts
	 */
	public function testUrlWithPathinfoAndSecondContextObjectIsNull() {
		$mockApplication = $this->_setUpMockEnvironment(self::PATHINFO_ENABLED);
		$_SERVER = array(
			'HOSTNAME' => 'mydomain.org',
			'SCRIPT_NAME' => '/index.php',
			'PATH_INFO' => '/current-context1/current-context2/$$$call$$$/current/component-class/current-op'
		);

		// Simulate context DAOs
		$this->_setUpMockDAOs('current-context1', 'current-context2', false, true);

		$result = $this->router->url($this->request);
		self::assertEquals('http://mydomain.org/index.php/current-context1/index/$$$call$$$/current/component-class/current-op', $result);
	}

	/**
	 * @covers PKPComponentRouter::url
	 * @covers PKPComponentRouter::_uncamelize
	 * @covers PKPComponentRouter::_urlCanonicalizeNewContext
	 * @covers PKPComponentRouter::_urlGetBaseAndContext
	 * @covers PKPComponentRouter::_urlGetAdditionalParameters
	 * @covers PKPComponentRouter::_urlFromParts
	 */
	public function testUrlWithoutPathinfo() {
		$mockApplication = $this->_setUpMockEnvironment(self::PATHINFO_DISABLED);
		$_SERVER = array(
			'HOSTNAME' => 'mydomain.org',
			'SCRIPT_NAME' => '/index.php',
		);
		$_GET = array(
			'firstContext' => 'current-context1',
			'secondContext' => 'current-context2',
			'component' => 'current.component-class',
			'op' => 'current-op'
		);

		// Simulate context DAOs
		$this->_setUpMockDAOs();

		$result = $this->router->url($this->request);
		self::assertEquals('http://mydomain.org/index.php?firstContext=current-context1&secondContext=current-context2&component=current.component-class&op=current-op', $result);

		$result = $this->router->url($this->request, 'new-context1');
		self::assertEquals('http://mydomain.org/index.php?firstContext=new-context1&secondContext=current-context2&component=current.component-class&op=current-op', $result);

		$result = $this->router->url($this->request, array('new-context1', 'new-context2'));
		self::assertEquals('http://mydomain.org/index.php?firstContext=new-context1&secondContext=new-context2&component=current.component-class&op=current-op', $result);

		$result = $this->router->url($this->request, array(), 'new.NewComponentHandler');
		self::assertEquals('http://mydomain.org/index.php?firstContext=current-context1&secondContext=current-context2&component=new.new-component&op=current-op', $result);

		$result = $this->router->url($this->request, array(), null, 'newOp');
		self::assertEquals('http://mydomain.org/index.php?firstContext=current-context1&secondContext=current-context2&component=current.component-class&op=new-op', $result);

		$result = $this->router->url($this->request, 'new-context1', 'new.NewComponentHandler');
		self::assertEquals('http://mydomain.org/index.php?firstContext=new-context1&secondContext=current-context2&component=new.new-component&op=current-op', $result);

		$result = $this->router->url($this->request, 'new-context1', 'new.NewComponentHandler', 'newOp');
		self::assertEquals('http://mydomain.org/index.php?firstContext=new-context1&secondContext=current-context2&component=new.new-component&op=new-op', $result);

		$result = $this->router->url($this->request, 'new-context1', null, 'newOp');
		self::assertEquals('http://mydomain.org/index.php?firstContext=new-context1&secondContext=current-context2&component=current.component-class&op=new-op', $result);

		$result = $this->router->url($this->request, 'new-context1', null, null, null,
			array(
				'key1' => 'val1?',
				'key2' => array('val2-1', 'val2?2')
			)
		);
		self::assertEquals('http://mydomain.org/index.php?firstContext=new-context1&secondContext=current-context2&component=current.component-class&op=current-op&key1=val1%3F&key2%5B%5D=val2-1&key2%5B%5D=val2%3F2', $result);

		$result = $this->router->url($this->request, 'new-context1', null, null, null, null, 'some?anchor');
		self::assertEquals('http://mydomain.org/index.php?firstContext=new-context1&secondContext=current-context2&component=current.component-class&op=current-op#some%3Fanchor', $result);

		$result = $this->router->url($this->request, 'new-context1', null, 'newOp', null, array('key' => 'val'), 'some-anchor');
		self::assertEquals('http://mydomain.org/index.php?firstContext=new-context1&secondContext=current-context2&component=current.component-class&op=new-op&key=val#some-anchor', $result);

		$result = $this->router->url($this->request, 'new-context1', null, null, null, array('key1' => 'val1', 'key2' => 'val2'), null, true);
		self::assertEquals('http://mydomain.org/index.php?firstContext=new-context1&amp;secondContext=current-context2&amp;component=current.component-class&amp;op=current-op&amp;key1=val1&amp;key2=val2', $result);
	}

	/**
	 * @covers PKPComponentRouter::url
	 * @covers PKPComponentRouter::_uncamelize
	 * @covers PKPComponentRouter::_urlCanonicalizeNewContext
	 * @covers PKPComponentRouter::_urlGetBaseAndContext
	 * @covers PKPComponentRouter::_urlGetAdditionalParameters
	 * @covers PKPComponentRouter::_urlFromParts
	 */
	public function testUrlWithoutPathinfoAndOverriddenBaseUrl() {
		$this->setTestConfiguration('request2', 'classes/core/config', false); // contains overridden context
		$mockApplication = $this->_setUpMockEnvironment(self::PATHINFO_DISABLED);
		$_SERVER = array(
			'HOSTNAME' => 'mydomain.org',
			'SCRIPT_NAME' => '/index.php',
		);
		$_GET = array(
			'firstContext' => 'overridden-context',
			'secondContext' => 'current-context2',
			'component' => 'current.component-class',
			'op' => 'current-op'
		);

		// Simulate context DAOs
		$this->_setUpMockDAOs('overridden-context');

		// NB: This also tests whether unusual URL elements like user, password and port
		// will be handled correctly.
		$result = $this->router->url($this->request);
		self::assertEquals('http://some-user:some-pass@some-domain:8080/?firstContext=xyz-context&secondContext=current-context2&component=current.component-class&op=current-op', $result);
	}

	/**
	 * @covers PKPComponentRouter::url
	 * @covers PKPComponentRouter::_uncamelize
	 * @covers PKPComponentRouter::_urlCanonicalizeNewContext
	 * @covers PKPComponentRouter::_urlGetBaseAndContext
	 * @covers PKPComponentRouter::_urlGetAdditionalParameters
	 * @covers PKPComponentRouter::_urlFromParts
	 */
	public function testUrlWithoutPathinfoAndSecondContextObjectIsNull() {
		$this->setTestConfiguration('request2', 'classes/core/config', false); // restful URLs enabled
		$mockApplication = $this->_setUpMockEnvironment(self::PATHINFO_DISABLED);
		$_SERVER = array(
			'HOSTNAME' => 'mydomain.org',
			'SCRIPT_NAME' => '/index.php',
		);
		$_GET = array(
			'firstContext' => 'current-context1',
			'secondContext' => 'current-context2',
			'component' => 'current.component-class',
			'op' => 'current-op'
		);

		// Simulate context DAOs
		$this->_setUpMockDAOs('current-context1', 'current-context2', false, true);

		// NB: This also tests whether restful URLs work correctly.
		$result = $this->router->url($this->request);
		self::assertEquals('http://mydomain.org/?firstContext=current-context1&secondContext=index&component=current.component-class&op=current-op', $result);
	}
}
?>
